# EMAIL ADDRESS

This is an NLP++ Analyzer that parses through text and identifies email addresses listed in the text. A variety of email-id formats are recognized. Some sample addresses can be found in input/text.txt
From each email-id,the information on the local-name, the domain-name and the top level domain(tld) is extracted and made available in the json format. A sample output can be found(for the sample text) in input/text.text_log/output.json.

To run the analyzer, create a text file in input folder consisting of the text to be parsed.
